This is an automated email from the ASF dual-hosted git repository.

github-actions[bot] pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/camel-k.git


The following commit(s) were added to refs/heads/main by this push:
     new 9f0dfa180 chore: nightly automatic updates
9f0dfa180 is described below

commit 9f0dfa180e9b23e3ecccda0e2ec438c5482851fb
Author: github-actions[bot] 
<41898282+github-actions[bot]@users.noreply.github.com>
AuthorDate: Thu Jun 18 00:03:31 2026 +0000

    chore: nightly automatic updates
---
 README.adoc                                        |  2 +-
 docs/antora.yml                                    |  2 +-
 docs/modules/ROOT/partials/apis/camel-k-crds.adoc  |  6 ++++--
 docs/modules/traits/pages/health.adoc              |  2 +-
 helm/camel-k/crds/camel-k-crds.yaml                | 22 ++++++++++++----------
 pkg/apis/camel/v1/zz_generated.deepcopy.go         |  1 -
 .../applyconfiguration/camel/v1/pipecondition.go   | 16 +++++++++-------
 .../camel.apache.org_integrationplatforms.yaml     |  4 ++--
 .../camel.apache.org_integrationprofiles.yaml      |  4 ++--
 .../crd/bases/camel.apache.org_integrations.yaml   |  4 ++--
 .../config/crd/bases/camel.apache.org_pipes.yaml   | 10 ++++++----
 11 files changed, 40 insertions(+), 33 deletions(-)

diff --git a/README.adoc b/README.adoc
index 676da38a3..ad764c320 100644
--- a/README.adoc
+++ b/README.adoc
@@ -8,7 +8,7 @@ 
image:https://goreportcard.com/badge/github.com/apache/camel-k["Go Report Card",
 image:https://godoc.org/github.com/apache/camel-k?status.svg["GoDoc";, 
link="https://godoc.org/github.com/apache/camel-k";]
 image:https://github.com/apache/camel-k/workflows/build/badge.svg["Build";, 
link="https://github.com/apache/camel-k/actions/workflows/build.yml";]
 
image:https://github.com/apache/camel-k/actions/workflows/nightly-release.yml/badge.svg["Nightly
 releases", 
link="https://github.com/apache/camel-k/actions/workflows/nightly-release.yml";]
-image:https://img.shields.io/badge/Coverage-62.7-yellow.svg["Code coverage"]
+image:https://img.shields.io/badge/Coverage-62.8-yellow.svg["Code coverage"]
 image:https://img.shields.io/badge/zulip-join_chat-brightgreen.svg["Chat on 
Zulip", link="https://camel.zulipchat.com";]
 
 Apache Camel K is a lightweight integration framework built from **Apache 
Camel** that runs natively on Kubernetes and is specifically designed for 
serverless and microservice architectures. Users of `Camel K` can instantly run 
integration code written in Camel DSL on their preferred **Cloud** provider.
diff --git a/docs/antora.yml b/docs/antora.yml
index 53a699b6a..5a4e633a1 100644
--- a/docs/antora.yml
+++ b/docs/antora.yml
@@ -38,6 +38,6 @@ asciidoc:
     kustomize-version: 5.7.1
     kubernetes-api-version: 0.36.1
     operator-fwk-api-version: 0.44.0
-    knative-api-version: 0.49.1
+    knative-api-version: 0.49.2
     service-binding-op-version: ""
     prometheus-op-version: 0.91.0
diff --git a/docs/modules/ROOT/partials/apis/camel-k-crds.adoc 
b/docs/modules/ROOT/partials/apis/camel-k-crds.adoc
index e37f02894..08bc344b0 100644
--- a/docs/modules/ROOT/partials/apis/camel-k-crds.adoc
+++ b/docs/modules/ROOT/partials/apis/camel-k-crds.adoc
@@ -4812,7 +4812,9 @@ A human readable message indicating details about the 
transition.
 |
 
 
-Pods collect health and conditions information from the owned PODs
+DeprecatedPods collect health and conditions information from the owned PODs
+
+Deprecated: may be removed in future releases.
 
 
 |===
@@ -7721,7 +7723,7 @@ int32
 |
 
 
-Minimum consecutive failures for the startup probe to be considered failed 
after having succeeded (default 6 if not specified).
+Minimum consecutive failures for the startup probe to be considered failed 
after having succeeded (default 10 if not specified).
 
 |`startupProbe` +
 string
diff --git a/docs/modules/traits/pages/health.adoc 
b/docs/modules/traits/pages/health.adoc
index 5756baddc..c52ddd115 100755
--- a/docs/modules/traits/pages/health.adoc
+++ b/docs/modules/traits/pages/health.adoc
@@ -134,7 +134,7 @@ The following configuration options are available:
 
 | health.startupFailureThreshold
 | int32
-| Minimum consecutive failures for the startup probe to be considered failed 
after having succeeded (default 6 if not specified).
+| Minimum consecutive failures for the startup probe to be considered failed 
after having succeeded (default 10 if not specified).
 
 | health.startupProbe
 | string
diff --git a/helm/camel-k/crds/camel-k-crds.yaml 
b/helm/camel-k/crds/camel-k-crds.yaml
index 6b75eb24e..d7e4253e4 100644
--- a/helm/camel-k/crds/camel-k-crds.yaml
+++ b/helm/camel-k/crds/camel-k-crds.yaml
@@ -4589,7 +4589,7 @@ spec:
                       startupFailureThreshold:
                         description: Minimum consecutive failures for the 
startup
                           probe to be considered failed after having succeeded 
(default
-                          6 if not specified).
+                          10 if not specified).
                         format: int32
                         type: integer
                       startupInitialDelay:
@@ -7120,7 +7120,7 @@ spec:
                       startupFailureThreshold:
                         description: Minimum consecutive failures for the 
startup
                           probe to be considered failed after having succeeded 
(default
-                          6 if not specified).
+                          10 if not specified).
                         format: int32
                         type: integer
                       startupInitialDelay:
@@ -9545,7 +9545,7 @@ spec:
                       startupFailureThreshold:
                         description: Minimum consecutive failures for the 
startup
                           probe to be considered failed after having succeeded 
(default
-                          6 if not specified).
+                          10 if not specified).
                         format: int32
                         type: integer
                       startupInitialDelay:
@@ -11956,7 +11956,7 @@ spec:
                       startupFailureThreshold:
                         description: Minimum consecutive failures for the 
startup
                           probe to be considered failed after having succeeded 
(default
-                          6 if not specified).
+                          10 if not specified).
                         format: int32
                         type: integer
                       startupInitialDelay:
@@ -21223,7 +21223,7 @@ spec:
                       startupFailureThreshold:
                         description: Minimum consecutive failures for the 
startup
                           probe to be considered failed after having succeeded 
(default
-                          6 if not specified).
+                          10 if not specified).
                         format: int32
                         type: integer
                       startupInitialDelay:
@@ -23595,7 +23595,7 @@ spec:
                       startupFailureThreshold:
                         description: Minimum consecutive failures for the 
startup
                           probe to be considered failed after having succeeded 
(default
-                          6 if not specified).
+                          10 if not specified).
                         format: int32
                         type: integer
                       startupInitialDelay:
@@ -34225,7 +34225,7 @@ spec:
                           startupFailureThreshold:
                             description: Minimum consecutive failures for the 
startup
                               probe to be considered failed after having 
succeeded
-                              (default 6 if not specified).
+                              (default 10 if not specified).
                             format: int32
                             type: integer
                           startupInitialDelay:
@@ -36519,7 +36519,7 @@ spec:
                       startupFailureThreshold:
                         description: Minimum consecutive failures for the 
startup
                           probe to be considered failed after having succeeded 
(default
-                          6 if not specified).
+                          10 if not specified).
                         format: int32
                         type: integer
                       startupInitialDelay:
@@ -37826,8 +37826,10 @@ spec:
                         the transition.
                       type: string
                     pods:
-                      description: Pods collect health and conditions 
information
-                        from the owned PODs
+                      description: |-
+                        DeprecatedPods collect health and conditions 
information from the owned PODs
+
+                        Deprecated: may be removed in future releases.
                       items:
                         description: 'Deprecated: may be removed in future 
releases.'
                         properties:
diff --git a/pkg/apis/camel/v1/zz_generated.deepcopy.go 
b/pkg/apis/camel/v1/zz_generated.deepcopy.go
index a4d9cdb16..f267d2733 100644
--- a/pkg/apis/camel/v1/zz_generated.deepcopy.go
+++ b/pkg/apis/camel/v1/zz_generated.deepcopy.go
@@ -6,7 +6,6 @@ package v1
 
 import (
        "encoding/json"
-
        "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
        corev1 "k8s.io/api/core/v1"
        metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
diff --git 
a/pkg/resources/config/crd/bases/camel.apache.org_integrationplatforms.yaml 
b/pkg/resources/config/crd/bases/camel.apache.org_integrationplatforms.yaml
index 389e25331..953987bc4 100644
--- a/pkg/resources/config/crd/bases/camel.apache.org_integrationplatforms.yaml
+++ b/pkg/resources/config/crd/bases/camel.apache.org_integrationplatforms.yaml
@@ -1288,7 +1288,7 @@ spec:
                       startupFailureThreshold:
                         description: Minimum consecutive failures for the 
startup
                           probe to be considered failed after having succeeded 
(default
-                          6 if not specified).
+                          10 if not specified).
                         format: int32
                         type: integer
                       startupInitialDelay:
@@ -3819,7 +3819,7 @@ spec:
                       startupFailureThreshold:
                         description: Minimum consecutive failures for the 
startup
                           probe to be considered failed after having succeeded 
(default
-                          6 if not specified).
+                          10 if not specified).
                         format: int32
                         type: integer
                       startupInitialDelay:
diff --git 
a/pkg/resources/config/crd/bases/camel.apache.org_integrationprofiles.yaml 
b/pkg/resources/config/crd/bases/camel.apache.org_integrationprofiles.yaml
index ba8143b44..3a445c948 100644
--- a/pkg/resources/config/crd/bases/camel.apache.org_integrationprofiles.yaml
+++ b/pkg/resources/config/crd/bases/camel.apache.org_integrationprofiles.yaml
@@ -1146,7 +1146,7 @@ spec:
                       startupFailureThreshold:
                         description: Minimum consecutive failures for the 
startup
                           probe to be considered failed after having succeeded 
(default
-                          6 if not specified).
+                          10 if not specified).
                         format: int32
                         type: integer
                       startupInitialDelay:
@@ -3557,7 +3557,7 @@ spec:
                       startupFailureThreshold:
                         description: Minimum consecutive failures for the 
startup
                           probe to be considered failed after having succeeded 
(default
-                          6 if not specified).
+                          10 if not specified).
                         format: int32
                         type: integer
                       startupInitialDelay:
diff --git a/pkg/resources/config/crd/bases/camel.apache.org_integrations.yaml 
b/pkg/resources/config/crd/bases/camel.apache.org_integrations.yaml
index d52a59c3f..c8efb8168 100644
--- a/pkg/resources/config/crd/bases/camel.apache.org_integrations.yaml
+++ b/pkg/resources/config/crd/bases/camel.apache.org_integrations.yaml
@@ -7991,7 +7991,7 @@ spec:
                       startupFailureThreshold:
                         description: Minimum consecutive failures for the 
startup
                           probe to be considered failed after having succeeded 
(default
-                          6 if not specified).
+                          10 if not specified).
                         format: int32
                         type: integer
                       startupInitialDelay:
@@ -10363,7 +10363,7 @@ spec:
                       startupFailureThreshold:
                         description: Minimum consecutive failures for the 
startup
                           probe to be considered failed after having succeeded 
(default
-                          6 if not specified).
+                          10 if not specified).
                         format: int32
                         type: integer
                       startupInitialDelay:
diff --git a/pkg/resources/config/crd/bases/camel.apache.org_pipes.yaml 
b/pkg/resources/config/crd/bases/camel.apache.org_pipes.yaml
index fa191373b..2b094b431 100644
--- a/pkg/resources/config/crd/bases/camel.apache.org_pipes.yaml
+++ b/pkg/resources/config/crd/bases/camel.apache.org_pipes.yaml
@@ -8046,7 +8046,7 @@ spec:
                           startupFailureThreshold:
                             description: Minimum consecutive failures for the 
startup
                               probe to be considered failed after having 
succeeded
-                              (default 6 if not specified).
+                              (default 10 if not specified).
                             format: int32
                             type: integer
                           startupInitialDelay:
@@ -10340,7 +10340,7 @@ spec:
                       startupFailureThreshold:
                         description: Minimum consecutive failures for the 
startup
                           probe to be considered failed after having succeeded 
(default
-                          6 if not specified).
+                          10 if not specified).
                         format: int32
                         type: integer
                       startupInitialDelay:
@@ -11647,8 +11647,10 @@ spec:
                         the transition.
                       type: string
                     pods:
-                      description: Pods collect health and conditions 
information
-                        from the owned PODs
+                      description: |-
+                        DeprecatedPods collect health and conditions 
information from the owned PODs
+
+                        Deprecated: may be removed in future releases.
                       items:
                         description: 'Deprecated: may be removed in future 
releases.'
                         properties:

Reply via email to
diff --git a/pkg/client/camel/applyconfiguration/camel/v1/pipecondition.go 
b/pkg/client/camel/applyconfiguration/camel/v1/pipecondition.go
index 37d164a8b..3ec794519 100644
--- a/pkg/client/camel/applyconfiguration/camel/v1/pipecondition.go
+++ b/pkg/client/camel/applyconfiguration/camel/v1/pipecondition.go
@@ -42,8 +42,10 @@ type PipeConditionApplyConfiguration struct {
        Reason *string `json:"reason,omitempty"`
        // A human readable message indicating details about the transition.
        Message *string `json:"message,omitempty"`
-       // Pods collect health and conditions information from the owned PODs
-       Pods []PodConditionApplyConfiguration `json:"pods,omitempty"`
+       // DeprecatedPods collect health and conditions information from the 
owned PODs
+       //
+       // Deprecated: may be removed in future releases.
+       DeprecatedPods []PodConditionApplyConfiguration `json:"pods,omitempty"`
 }
 
 // PipeConditionApplyConfiguration constructs a declarative configuration of 
the PipeCondition type for use with
@@ -100,15 +102,15 @@ func (b *PipeConditionApplyConfiguration) 
WithMessage(value string) *PipeConditi
        return b
 }
 
-// WithPods adds the given value to the Pods field in the declarative 
configuration
+// WithDeprecatedPods adds the given value to the DeprecatedPods field in the 
declarative configuration
 // and returns the receiver, so that objects can be build by chaining "With" 
function invocations.
-// If called multiple times, values provided by each call will be appended to 
the Pods field.
-func (b *PipeConditionApplyConfiguration) WithPods(values 
...*PodConditionApplyConfiguration) *PipeConditionApplyConfiguration {
+// If called multiple times, values provided by each call will be appended to 
the DeprecatedPods field.
+func (b *PipeConditionApplyConfiguration) WithDeprecatedPods(values 
...*PodConditionApplyConfiguration) *PipeConditionApplyConfiguration {
        for i := range values {
                if values[i] == nil {
-                       panic("nil value passed to WithPods")
+                       panic("nil value passed to WithDeprecatedPods")
                }
-               b.Pods = append(b.Pods, *values[i])
+               b.DeprecatedPods = append(b.DeprecatedPods, *values[i])
        }
        return b
 }